#
# spec file for package ghc-flat-mcmc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name flat-mcmc
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.5.0
Release:        lp150.3.3
Summary:        Painless general-purpose sampling
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-formatting-devel
BuildRequires:  ghc-mcmc-types-devel
BuildRequires:  ghc-monad-par-devel
BuildRequires:  ghc-monad-par-extras-devel
BuildRequires:  ghc-mwc-probability-devel
BuildRequires:  ghc-pipes-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-vector-devel

%description
Flat-mcmc is a Haskell library for painless, efficient, general-purpose
sampling from continuous distributions.

flat-mcmc uses an ensemble sampler that is invariant to affine transformations
of space. It wanders a target probability distribution's parameter space as if
it had been "flattened" or "unstretched" in some sense, allowing many particles
to explore it locally and in parallel.

In general this sampler is useful when you want decent performance without
dealing with any tuning parameters or local proposal distributions.

flat-mcmc exports an 'mcmc' function that prints a trace to stdout, as well as
a 'flat' transition operator that can be used more generally.

> import Numeric.MCMC.Flat > import qualified Data.Vector.Unboxed as U
(unsafeIndex) > > rosenbrock :: Particle -> Double > rosenbrock xs = negate (5
* (x1 - x0 ^ 2) ^ 2 + 0.05 * (1 - x0) ^ 2) where > x0 = U.unsafeIndex xs 0 > x1
= U.unsafeIndex xs 1 > > origin :: Ensemble > origin = ensemble [ > particle
[negate 1.0, negate 1.0] > , particle [negate 1.0, 1.0] > , particle [1.0,
negate 1.0] > , particle [1.0, 1.0] > ] > > main :: IO () > main =
withSystemRandom . asGenIO $ mcmc 12500 origin rosenbrock.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files

%changelog
* Tue Jul 10 2018 psimons@suse.com
- Add flat-mcmc at version 1.5.0.
